import QtQuick
import QtQuick.Layouts
import Quickshell
import "widgets" as Widgets

PanelWindow {

    property var weatherConfig: ({})
    property string sysInfoInterval: "2s"
    property int workspaces: 10

    anchors {
        top: true
        left: true
        right: true
    }

    height: 46
    width: 500
    color: "transparent"

    Rectangle {
        anchors.leftMargin: 10
        anchors.rightMargin: 10
        anchors.topMargin: 5
        anchors.fill: parent
        color: "#141418"
        radius: 25

        ShaderEffect {
            id: shaderEffect
            anchors.fill: parent
            property color baseColor: "#191823"
            property color transparent: Qt.rgba(0, 0, 0, 0)
            property real rectWidth: parent.width
            property real rectHeight: parent.height
            property real cornerRadius: 25.0
            property real time: 0.0
            fragmentShader: "gradient.frag.qsb"
        }

        RowLayout {
            anchors.fill: parent

            Item {
                Layout.fillWidth: true
                Layout.fillHeight: true
                RowLayout {
                    anchors.left: parent.left
                    anchors.top: parent.top
                    anchors.bottom: parent.bottom
                    spacing: 10
                    Widgets.Workspaces {
                        Layout.fillHeight: true
                        workspaces: workspaces
                    }
                    Widgets.NowPlaying {
                        Layout.fillHeight: true
                    }
                }
            }

            Widgets.ActiveWindow {
                Layout.fillHeight: true
            }

            Item {
                Layout.fillWidth: true
                Layout.fillHeight: true
                RowLayout {
                    spacing: 10
                    anchors.right: parent.right
                    anchors.top: parent.top
                    anchors.bottom: parent.bottom
                    Widgets.Stats {
                        Layout.fillHeight: true
                        updateInterval: sysInfoInterval
                    }
                    Widgets.Weather {
                        Layout.fillHeight: true
                        isAmerican: weatherConfig.isamerican ?? false
                        city: weatherConfig.city ?? "London"
                        updateInterval: weatherConfig.weatherupdateinterval ?? 300000
                    }
                    Widgets.Power {
                        Layout.fillHeight: true
                    }
                    Widgets.SystemTray {
                        Layout.fillHeight: true
                    }
                    Widgets.Clock {
                        Layout.fillHeight: true
                    }
                }
            }
        }
    }
}
