#version 440

layout(location = 0) in vec2 qt_TexCoord0;
layout(location = 0) out vec4 fragColor;

layout(std140, binding = 0) uniform buf {
    mat4 qt_Matrix;
    float qt_Opacity;
    vec4 baseColor;
    vec4 transparent;
    float rectWidth;
    float rectHeight;
    float cornerRadius;
    float time;  // Add time uniform
} ubuf;

// Distance field for rounded rectangle
float roundedRectDF(vec2 pt, vec2 size, float radius) {
    vec2 d = abs(pt - size/2.0) - size/2.0 + radius;
    return length(max(d, 0.0)) + min(max(d.x, d.y), 0.0) - radius;
}

void main() {
    vec2 pos = qt_TexCoord0;
    
    // Create stripes with animated offset
    float pattern = mod(pos.x * 1.0 + pos.y * 0.0167 - ubuf.time * 0.2, 1.0);
    
    vec4 color;
    if (pattern < 0.18) color = ubuf.baseColor;
    else if (pattern < 0.37) color = ubuf.transparent;
    else if (pattern < 0.63) color = ubuf.baseColor;
    else if (pattern < 0.85) color = ubuf.transparent;
    else color = ubuf.baseColor;
    
    // Calculate corner mask
    vec2 pixelPos = pos * vec2(ubuf.rectWidth, ubuf.rectHeight);
    float df = roundedRectDF(pixelPos, vec2(ubuf.rectWidth, ubuf.rectHeight), ubuf.cornerRadius);
    float mask = 1.0 - smoothstep(-1.0, 0.0, df);
    
    // Apply both color and mask
    fragColor = color * ubuf.qt_Opacity * mask;
}