import QtQuick
import QtQuick.Controls
import QtQuick.Layouts
import Quickshell
import "root:/"

BarTooltip {
    id: calendarTooltip
    required property bool calendarOpen
    required property Item clockLayout
    relativeItem: calendarOpen ? clockLayout : null
    hoverable: true
    showBackground: false
    hideDelay: 0

    Rectangle {
        color: "#141418"  // Darker background to match bar
        radius: 12
        border.color: "#40ffffff"
        border.width: 1
        width: 260
        height: 280

        ColumnLayout {
            anchors.fill: parent
            anchors.margins: 16
            spacing: 12

            // Month/Year header with navigation
            RowLayout {
                Layout.fillWidth: true
                spacing: 8

                IconButton {
                    icon: "go-previous"
                    onClicked: {
                        let newDate = new Date(calendar.year, calendar.month - 1, 1);
                        calendar.year = newDate.getFullYear();
                        calendar.month = newDate.getMonth();
                    }
                }

                Text {
                    Layout.fillWidth: true
                    horizontalAlignment: Text.AlignHCenter
                    text: calendar.title
                    color: Globals.commonStyles.textColor
                    opacity: 0.7
                    font.pixelSize: Globals.commonStyles.tooltipFontSize
                    font.family: Globals.commonStyles.fontFamily
                    font.weight: Globals.commonStyles.fontWeight
                }

                IconButton {
                    icon: "go-next"
                    onClicked: {
                        let newDate = new Date(calendar.year, calendar.month + 1, 1);
                        calendar.year = newDate.getFullYear();
                        calendar.month = newDate.getMonth();
                    }
                }
            }

            DayOfWeekRow {
                Layout.fillWidth: true
                spacing: 0
                Layout.leftMargin: 8  // Align with grid
                Layout.rightMargin: 8
                delegate: Text {
                    text: shortName
                    color: Globals.commonStyles.textColor
                    opacity: 0.8
                    font.pixelSize: Globals.commonStyles.smallTextFontSize
                    font.family: Globals.commonStyles.fontFamily
                    font.weight: Globals.commonStyles.fontWeight
                    horizontalAlignment: Text.AlignHCenter
                    width: 32
                }
            }

            MonthGrid {
                id: calendar
                Layout.fillWidth: true
                Layout.leftMargin: 8
                Layout.rightMargin: 8
                spacing: 0
                month: Globals.date.getMonth()
                year: Globals.date.getFullYear()

                delegate: Rectangle {
                    width: 32
                    height: 32
                    radius: 8
                    color: {
                        if (model.today)
                            return "#3daee9";
                        if (mouseArea2.containsMouse)
                            return "#40ffffff";
                        return "transparent";
                    }

                    Text {
                        anchors.centerIn: parent
                        text: model.day
                        color: Globals.commonStyles.textColor
                        opacity: model.month === calendar.month ? (mouseArea2.containsMouse ? 1.0 : 0.7) : 0.3
                        font.pixelSize: Globals.commonStyles.smallTextFontSize
                        font.family: Globals.commonStyles.fontFamily
                        font.weight: model.today ? Font.Bold : Globals.commonStyles.fontWeight
                    }

                    MouseArea {
                        id: mouseArea2
                        anchors.fill: parent
                        hoverEnabled: true
                    }

                    Behavior on color {
                        ColorAnimation {
                            duration: 150
                        }
                    }
                }
            }
        }
    }
}
