import QtQuick
import QtQuick.Layouts
import Quickshell
import Quickshell.Services.UPower
import "root:/"

Loader {
    visible: UPower.displayDevice != null && UPower.displayDevice.type === UPowerDeviceType.Battery
    active: visible

    sourceComponent: MouseArea {
        id: mouseArea
        hoverEnabled: true

        implicitWidth: widget.implicitWidth
        implicitHeight: widget.implicitHeight

        BarWidget {
            id: widget
            anchors.fill: parent
            color: "transparent"

            RowLayout {
                anchors.fill: parent
                spacing: 5

                Text {
                    font.family: Globals.commonStyles.iconFontFamily
                    font.pixelSize: Globals.commonStyles.iconFontSize
                    color: Globals.commonStyles.textColor
                    text: {
                        const device = UPower.displayDevice;
                        const percentage = device.percentage;

                        if (device.state === UPowerDeviceState.Charging) {
                            return "battery_charging_full";
                        }
                        if (device.state === UPowerDeviceState.FullyCharged) {
                            return "battery_full";
                        }

                        const batteryLevel = Math.floor(6 * percentage);
                        return `battery_${batteryLevel}_bar`;
                    }
                }

                Text {
                    font.family: Globals.commonStyles.fontFamily
                    font.weight: Globals.commonStyles.fontWeight
                    font.pixelSize: Globals.commonStyles.textFontSize
                    color: Globals.commonStyles.textColor
                    text: `${Math.floor(UPower.displayDevice.percentage * 100)}%`
                }
            }
        }

        BarTooltip {
            id: powerTooltip
            hideDelay: 0
            relativeItem: mouseArea.containsMouse ? widget : null
            contentDelegate: Text {
                text: {
                    const device = UPower.displayDevice;

                    let state = UPowerDeviceState.toString(device.state);
                    switch (device.state) {
                    case UPowerDeviceState.Charging:
                        state = "Charging";
                        break;
                    case UPowerDeviceState.PendingCharge:
                        state = "Not Charging";
                        break;
                    case UPowerDeviceState.Discharging:
                        state = "Discharging";
                        break;
                    case UPowerDeviceState.FullyCharged:
                        state = "Fully Charged";
                        break;
                    }

                    const time = device.timeToEmpty || device.timeToFull;
                    if (time != 0) {
                        if (state != "")
                            state += "\n";
                        const minutes = Math.floor(time / 60).toString().padStart(2, '0');
                        const seconds = (time % 60).toString().padStart(2, '0');
                        state += `${minutes}:${seconds} remains`;
                    }

                    return state;
                }
                color: Globals.commonStyles.textColor
                font.family: Globals.commonStyles.fontFamily
                font.pixelSize: Globals.commonStyles.tooltipFontSize
                font.weight: Globals.commonStyles.fontWeight
                horizontalAlignment: Text.AlignHCenter
            }
        }
    }
}
