import QtQuick
import Quickshell
import Quickshell.Io
import QtQuick.Layouts
import QtQuick.Controls
import "root:/"

BarWidget {
    id: root
    color: "transparent"
    implicitHeight: 42
    implicitWidth: mainRect.width

    property string updateInterval: "2s"
    property string cpuUsage: ""
    property string cpuTemp: ""
    property string memoryUsage: ""

    Process {
        id: gostatProcess
        running: true
        command: [Quickshell.shellRoot + "/programs/gostat", root.updateInterval]
        stdout: SplitParser {
            onRead: function (line) {
                try {
                    const data = JSON.parse(line);
                    root.cpuUsage = data.cpu + "%";
                    root.cpuTemp = data.cputemp + "°C";
                    root.memoryUsage = data.mem + "G";
                } catch (e) {
                    console.error("Failed to parse gostat output:", e);
                }
            }
        }
    }

    Rectangle {
        id: mainRect
        height: parent.height
        width: layout.width
        color: "transparent"
        radius: 8

        RowLayout {
            id: layout
            anchors.centerIn: parent
            spacing: 20

            // CPU Usage Component
            Item {
                Layout.preferredHeight: cpuUsageLayout.height
                Layout.preferredWidth: cpuUsageLayout.width

                MouseArea {
                    id: cpuMouseArea
                    width: cpuUsageLayout.width
                    height: cpuUsageLayout.height
                    hoverEnabled: true
                    onEntered: cpuTooltip.relativeItem = cpuUsageLayout
                    onExited: cpuTooltip.relativeItem = null

                    RowLayout {
                        id: cpuUsageLayout
                        spacing: 5
                        Text {
                            font.family: Globals.commonStyles.iconFontFamily
                            font.pixelSize: Globals.commonStyles.iconFontSize
                            text: "developer_board"
                            color: Globals.commonStyles.textColor
                        }

                        Text {
                            font.family: Globals.commonStyles.fontFamily
                            font.pixelSize: Globals.commonStyles.textFontSize
                            color: Globals.commonStyles.textColor
                            text: root.cpuUsage
                            font.weight: Globals.commonStyles.fontWeight
                            verticalAlignment: Text.AlignVCenter
                        }
                    }
                }

                BarTooltip {
                    id: cpuTooltip
                    hideDelay: 0
                    contentDelegate: Text {
                        text: "CPU Usage\n" + root.cpuUsage
                        color: Globals.commonStyles.tooltipTextColor
                        font.family: Globals.commonStyles.fontFamily
                        font.weight: Globals.commonStyles.fontWeight
                        font.pixelSize: Globals.commonStyles.tooltipFontSize
                        horizontalAlignment: Text.AlignHCenter
                    }
                }
            }

            // CPU Temperature Component
            Item {
                Layout.preferredHeight: cpuTempLayout.height
                Layout.preferredWidth: cpuTempLayout.width

                MouseArea {
                    id: tempMouseArea
                    width: cpuTempLayout.width
                    height: cpuTempLayout.height
                    hoverEnabled: true
                    onEntered: tempTooltip.relativeItem = cpuTempLayout
                    onExited: tempTooltip.relativeItem = null

                    RowLayout {
                        id: cpuTempLayout
                        spacing: 5
                        Text {
                            font.family: Globals.commonStyles.iconFontFamily
                            font.pixelSize: Globals.commonStyles.iconFontSize
                            text: "thermometer"
                            color: Globals.commonStyles.textColor
                        }

                        Text {
                            font.family: Globals.commonStyles.fontFamily
                            font.pixelSize: Globals.commonStyles.textFontSize
                            color: Globals.commonStyles.textColor
                            text: root.cpuTemp
                            verticalAlignment: Text.AlignVCenter
                            font.weight: Globals.commonStyles.fontWeight
                        }
                    }
                }

                BarTooltip {
                    id: tempTooltip
                    hideDelay: 0
                    contentDelegate: Text {
                        text: "CPU Temperature\n" + root.cpuTemp
                        color: Globals.commonStyles.tooltipTextColor
                        font.family: Globals.commonStyles.fontFamily
                        font.weight: Globals.commonStyles.fontWeight
                        font.pixelSize: Globals.commonStyles.tooltipFontSize
                        horizontalAlignment: Text.AlignHCenter
                    }
                }
            }

            // Memory Usage Component
            Item {
                Layout.preferredHeight: memoryUsageLayout.height
                Layout.preferredWidth: memoryUsageLayout.width

                MouseArea {
                    id: memMouseArea
                    width: memoryUsageLayout.width
                    height: memoryUsageLayout.height
                    hoverEnabled: true
                    onEntered: memTooltip.relativeItem = memoryUsageLayout
                    onExited: memTooltip.relativeItem = null

                    RowLayout {
                        id: memoryUsageLayout
                        spacing: 5
                        Text {
                            font.family: Globals.commonStyles.iconFontFamily
                            font.pixelSize: Globals.commonStyles.iconFontSize
                            text: "memory"
                            color: Globals.commonStyles.textColor
                        }

                        Text {
                            font.family: Globals.commonStyles.fontFamily
                            font.pixelSize: Globals.commonStyles.textFontSize
                            color: Globals.commonStyles.textColor
                            text: root.memoryUsage
                            font.weight: Globals.commonStyles.fontWeight
                            verticalAlignment: Text.AlignVCenter
                        }
                    }
                }

                BarTooltip {
                    id: memTooltip
                    hideDelay: 0
                    contentDelegate: Text {
                        text: "Memory Usage\n" + root.memoryUsage
                        color: Globals.commonStyles.tooltipTextColor
                        font.family: Globals.commonStyles.fontFamily
                        font.weight: Globals.commonStyles.fontWeight
                        font.pixelSize: Globals.commonStyles.tooltipFontSize
                        horizontalAlignment: Text.AlignHCenter
                    }
                }
            }
        }
    }
}
