import QtQuick
import QtQuick.Controls
import QtQuick.Layouts
import Quickshell
import Quickshell.Widgets
import Quickshell.Services.SystemTray
import "root:/"

BarWidget {
    id: root
    color: "transparent"

    // This removes BarWidget's implicit padding so the mouse areas of
    // each tray item cover as much area as possible.
    widgetAnchors.margins: 0
    widgetAnchors.leftMargin: 3
    widgetAnchors.rightMargin: 3

    RowLayout {
        anchors.fill: parent
        anchors.bottomMargin: 4
        spacing: 10

        Repeater {
            model: SystemTray.items

            MouseArea {
                id: delegate
                required property SystemTrayItem modelData
                property alias item: delegate.modelData

                Layout.fillHeight: true
                implicitWidth: icon.implicitWidth + 5

                acceptedButtons: Qt.LeftButton | Qt.RightButton | Qt.MiddleButton
                hoverEnabled: true

                onClicked: event => {
                    if (event.button == Qt.LeftButton) {
                        item.activate();
                    } else if (event.button == Qt.MiddleButton) {
                        item.secondaryActivate();
                    } else if (event.button == Qt.RightButton && item.hasMenu) {
                        const window = QsWindow.window;
                        const widgetRect = window.contentItem.mapFromItem(delegate, 0, delegate.height, delegate.width, delegate.height);

                        menuAnchor.anchor.rect = widgetRect;
                        menuAnchor.open();
                    }
                }

                onWheel: event => {
                    event.accepted = true;
                    const points = event.angleDelta.y / 120;
                    item.scroll(points, false);
                }

                IconImage {
                    id: icon
                    anchors.horizontalCenter: parent.horizontalCenter
                    anchors.verticalCenter: parent.verticalCenter
                    source: item && item.icon ? item.icon : ""
                    visible: status === Image.Ready
                    implicitSize: 24
                    smooth: true
                }
                BarTooltip {
                    relativeItem: delegate.containsMouse ? delegate : null
                    hoverable: true
                    showBackground: true
                    hideDelay: 0
                    Label {
                        font.family: Globals.commonStyles.fontFamily
                        font.pixelSize: Globals.commonStyles.tooltipFontSize
                        font.weight: Globals.commonStyles.fontWeight
                        color: Globals.commonStyles.textColor
                        text: delegate.item ? (delegate.item.tooltipTitle || delegate.item.id || "") : ""
                    }
                }

                QsMenuAnchor {
                    id: menuAnchor
                    menu: item.menu

                    anchor.window: delegate.QsWindow.window
                    anchor.adjustment: PopupAdjustment.Flip
                }
            }
        }
    }
}
