import QtQuick
import QtQuick.Layouts
import Quickshell
import Quickshell.Hyprland
import "root:/"

BarWidget {
    id: root
    color: "transparent"
    Layout.alignment: Qt.AlignLeft
    property int workspaces: 10
    Layout.fillHeight: true
    widgetAnchors.margins: 0

    RowLayout {
        anchors {
            left: parent.left
            leftMargin: 16
            verticalCenter: parent.verticalCenter
        }
        spacing: 0

        Repeater {
            model: root.workspaces

            Item {
                Layout.preferredWidth: 26
                Layout.preferredHeight: 26

                Rectangle {
                    id: wsRect
                    anchors.fill: parent

                    property int wsId: index + 1
                    property bool isActive: Hyprland.focusedMonitor?.activeWorkspace.id === wsId
                    property bool hasWindows: {
                        for (const ws of Hyprland.workspaces.values) {
                            if (ws.id === wsId)
                                return true;
                        }
                        return false;
                    }
                    property bool hasNextWindow: {
                        if (index < workspaces - 1) {
                            for (const ws of Hyprland.workspaces.values) {
                                if (ws.id === (wsId + 1))
                                    return true;
                            }
                        }
                        return false;
                    }
                    property bool hasPrevWindow: {
                        if (index > 0) {
                            for (const ws of Hyprland.workspaces.values) {
                                if (ws.id === (wsId - 1))
                                    return true;
                            }
                        }
                        return false;
                    }

                    color: {
                        if (mouseArea.containsMouse && wsRect.hasWindows)
                            return "#3e31ad";
                        if (isActive)
                            return "#c6c0ff";
                        if (hasWindows)
                            return "#464459";
                        return "transparent";
                    }
                    radius: 99

                    Rectangle {
                        z: -1
                        visible: wsRect.hasWindows
                        anchors.fill: parent
                        color: "#464459"
                        radius: 99

                        Rectangle {
                            visible: wsRect.hasNextWindow && wsRect.hasWindows
                            anchors {
                                right: parent.right
                                top: parent.top
                                bottom: parent.bottom
                                rightMargin: 0
                            }
                            width: parent.width / 2
                            color: parent.color
                            radius: 0
                        }

                        Rectangle {
                            visible: wsRect.hasPrevWindow && wsRect.hasWindows
                            anchors {
                                left: parent.left
                                top: parent.top
                                bottom: parent.bottom
                                leftMargin: 0
                            }
                            width: parent.width / 2
                            color: parent.color
                            radius: 0
                        }
                    }

                    Behavior on color {
                        ColorAnimation {
                            duration: 100
                            easing.type: Easing.Bezier
                            easing.bezierCurve: [0, 1, 0, 1]
                        }
                    }

                    states: [
                        State {
                            when: mouseArea.containsMouse && !wsRect.isActive && !wsRect.hasWindows
                            PropertyChanges {
                                target: wsText
                            }
                        },
                        State {
                            when: mouseArea.containsMouse && wsRect.hasWindows
                            PropertyChanges {
                                target: wsRect
                            }
                            PropertyChanges {
                                target: wsText
                            }
                        },
                        State {
                            when: mouseArea.containsMouse && wsRect.isActive
                            PropertyChanges {
                                target: wsRect
                            }
                            PropertyChanges {
                                target: wsText
                            }
                        }
                    ]

                    Text {
                        id: wsText
                        anchors.centerIn: parent
                        text: wsRect.wsId
                        horizontalAlignment: Text.AlignHCenter
                        verticalAlignment: Text.AlignVCenter
                        color: {
                            if (mouseArea.containsMouse) {
                                if (wsRect.isActive)
                                    return "#260f98";
                                if (wsRect.hasWindows)
                                    return "#e5dfff";
                                return "#c6c0ff";
                            }
                            if (wsRect.isActive)
                                return "#260f98";
                            if (wsRect.hasWindows)
                                return "#e3dff8";
                            return "#666666";
                        }
                        font.pixelSize: Globals.commonStyles.textFontSize
                        font.family: Globals.commonStyles.fontFamilySans
                        Behavior on color {
                            ColorAnimation {
                                duration: 100
                            }
                        }
                    }

                    MouseArea {
                        id: mouseArea
                        anchors.fill: parent
                        hoverEnabled: !wsRect.isActive
                        acceptedButtons: wsRect.isActive ? Qt.NoButton : Qt.LeftButton
                        onClicked: {
                            Hyprland.dispatch(`workspace ${wsRect.wsId}`);
                        }
                        onWheel: function (event) {
                            if (event.angleDelta.y > 0) {
                                if (Hyprland.focusedMonitor.activeWorkspace.id === root.workspaces) {
                                    return;
                                }
                                Hyprland.dispatch(`workspace +1`);
                            } else {
                                if (Hyprland.focusedMonitor.activeWorkspace.id === 1) {
                                    return;
                                }
                                Hyprland.dispatch(`workspace -1`);
                            }
                        }
                    }
                }
            }
        }
    }
}
